settitle

package module
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 7, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Overview

Package settitle provides a tool that allows an LLM to set the conversation title, which is broadcast to all conduits via PropertiesEvent.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Tool

func Tool() tool.ToolFunc

Tool returns a ToolFunc that sets the conversation title. Expected argument: "title" (string).

Types

type TitleUpdate

type TitleUpdate struct{ Title string }

TitleUpdate carries the new conversation title. It implements artifact.StatusContributor so the tool handler broadcasts the title change to all session subscribers via PropertiesEvent.

func (TitleUpdate) Status

func (t TitleUpdate) Status() map[string]string

Status returns the title as a map for PropertiesEvent.

Jump to