Documentation
¶
Overview ¶
Package settitle provides a tool that allows an LLM to set the conversation title, which is broadcast to all conduits via PropertiesEvent.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type TitleUpdate ¶
type TitleUpdate struct{ Title string }
TitleUpdate carries the new conversation title. It implements artifact.StatusContributor so the tool handler broadcasts the title change to all session subscribers via PropertiesEvent.
func (TitleUpdate) Status ¶
func (t TitleUpdate) Status() map[string]string
Status returns the title as a map for PropertiesEvent.
Click to show internal directories.
Click to hide internal directories.